@@ -1298,7 +1298,6 @@ The data @var{data} is loaded from the variable @var{varid} of the NetCDF file @
 
   int ncid = args(0).scalar_value();
   int varid = args(1).scalar_value ();
-  std::list<Range> ranges;
   int ndims;
   octave_value data;
   nc_type xtype, basetype;
@@ -1880,7 +1879,7 @@ This functions returns all variable ids in a NetCDF file or NetCDF group.\n\
 
 DEFUN_DLD(netcdf_inqVar, args,,
   "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {[@var{name},@var{nctype},@var{dimids},@var{nattr}] = } netcdf_inqVarID (@var{ncid},@var{varid}) \n\
+@deftypefn {Loadable Function} {[@var{name},@var{nctype},@var{dimids},@var{nattr}] = } netcdf_inqVar (@var{ncid},@var{varid}) \n\
 Inquires information about a NetCDF variable.\n\
 This functions returns the @var{name}, the NetCDF type @var{nctype}, an array of dimension ids \n\
 @var{dimids} and the number of attributes @var{nattr} of the NetCDF variable. @var{nctype} in an \n\
